@@ -1,4 +1,4 @@
-#%% begin initialize phpPgAdmin-4.2.3-noname-P1
+#%% begin initialize phpPgAdmin-5.0.2-noname-P1
 ###################################################################
 export LANG=C
 
@@ -11,7 +11,7 @@ PHP_DIR=$ROOT/opt/php5
 
 ( cd $ROOT/opt/htdocs;
   rm -f phpPgAdmin;
-  ln -sf  phpPgAdmin-4.2.3  phpPgAdmin;
+  ln -sf  phpPgAdmin-5.0.2  phpPgAdmin;
   /bin/su postgres -c 'psql -f phpPgAdmin/sql/reports-pgsql.sql';
 )
 
@@ -19,7 +19,7 @@ sed -e 's%usr/bin%opt/pgsql/bin%' \
     $ROOT/opt/htdocs/phpPgAdmin/conf/config.inc.php-dist \
     > $ROOT/opt/htdocs/phpPgAdmin/conf/config.inc.php
 
-/bin/chown -R wadm:apache $ROOT/opt/htdocs/phpPgAdmin-4.2.3
+/bin/chown -R wadm:apache $ROOT/opt/htdocs/phpPgAdmin-5.0.2
 
-/bin/su postgres -c '/opt/pgsql/bin/pg_passwd.sh www';
+#/bin/su postgres -c '/opt/pgsql/bin/pg_passwd.sh www';
 #%% end
